import { Reference } from './Reference.js';
interface FromOption {
    /** Reference to the collection */
    collection: Reference;
    /** Whether to make a compound query or not */
    allDescendants: boolean;
}
declare type FilterOption = [
/** Property name */
string, 
/** Operator */
'<' | '<=' | '>' | '>=' | '==' | 'contains', 
/** The value to compare against */
any];
interface OrderOption {
    /** The field path to use while ordering */
    field: string;
    /** The direction to order by */
    direction?: 'asc' | 'desc';
}
interface CursorOption {
    /** A reference to a document */
    reference: Reference;
    /** If the position is before or just after the given values */
    before: boolean;
}
interface QueryOptions {
    [key: string]: any;
    /** The fields to return, leave empty to return the whole doc. */
    select?: string[];
    /** The collection to query, Should be set automatically if you are using `ref.query()` */
    from: Reference | FromOption;
    /** Filter used to select matching documents */
    where?: FilterOption[];
    /** The field to use while ordering the results and direction */
    orderBy?: string | OrderOption | Array<string | OrderOption>;
    /** Reference to a document from which to start the query */
    startAt?: Reference | CursorOption;
    /** Reference to a document at which to end the query */
    endAt?: Reference | CursorOption;
    /** The number of results to skip */
    offset?: number;
    /** The max amount of documents to return */
    limit?: number;
}
/**
 * Query class that represents a Firestore query.
 */
export declare class Query {
    [key: string]: any;
    private db;
    private parentDocument;
    private options;
    constructor(init?: QueryOptions);
    select(fields: QueryOptions['select']): void;
    /**
     * Adds a collection to query.
     */
    from(val: QueryOptions['from']): this;
    where(fieldPath: QueryOptions['where']): this;
    orderBy(order: QueryOptions['orderBy'], dir?: OrderOption['direction']): this;
    startAt(ref: QueryOptions['startAt']): this;
    endAt(ref: QueryOptions['endAt']): this;
    offset(number: number): this;
    limit(number: number): this;
    run(): Promise<any>;
    toJSON(): {
        structuredQuery: any;
    };
}
export {};
